<?php

/*** Sets up the content width value based on the theme's design. ***/
if ( ! isset( $content_width ) )
	$content_width = 604;



/*** Sets up theme defaults and registers the various WordPress features that Three Star supports. ***/
function threestar_setup() {
	/*** Makes Three Star available for translation. ***/
	load_theme_textdomain( 'threestar', get_template_directory() . '/languages' );

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	// Switches default core markup for search form, comment form, and comments
	// to output valid HTML5.
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );

	/*
	 * This theme supports all available post formats by default.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video'
	) );

	// This theme uses wp_nav_menu() in one location.
	register_nav_menu( 'primary', __( 'Navigation Menu', 'threestar' ) );

	/*
	 * This theme uses a custom image size for featured images, displayed on
	 * "standard" posts and pages.
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 604, 270, true );

	// This theme uses its own gallery styles.
	add_filter( 'use_default_gallery_style', '__return_false' );
}
add_action( 'after_setup_theme', 'threestar_setup' );


/*** Creates a nicely formatted and more specific title element text for output in head of document, based on current view. ***/
function threestar_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'threestar' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'threestar_wp_title', 10, 2 );

/*** Enqueues scripts and styles for front end. ***/
function threestar_scripts_styles() {
	// Adds JavaScript to pages with the comment form to support sites with threaded comments (when in use).
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

}
add_action( 'wp_enqueue_scripts', 'threestar_scripts_styles' );

/*** Registers two widget areas. ****/
function threestar_widgets_init() {
    register_sidebar( array(
	'name'          => __( 'ThreeStar Siderbar Widget Area', 'threestar' ),
	'id'            => 'sidebar-1',
	'description'   => __( 'Appears in the footer section of the site.', 'threestar' ),
	'before_widget' => '<aside id="%1$s" class="widget %2$s">',
	'after_widget'  => '</aside>',
	'before_title'  => '<h1 class="widget-title page-title services">',
	'after_title'   => '</h1>',
	) );
	register_sidebar( array(
	'name' => __( 'ThreeStar Footer Widget Area One', 'threestar'),
	'id' => 'threestarfooterwidget1',
	'description' => __( 'Note: In order to use this widget area you need to enable the sidebar from Theme Manager&acute;s Manage Sidebar option.', 'threestar_setup' ),
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h2 class="widget-title">',
	'after_title' => '</h2>',
	) );
	register_sidebar( array(
	'name' => __( 'ThreeStar Footer Widget Area Two', 'threestar'),
	'id' => 'threestarfooterwidget2',
	'description' => __( 'Note: In order to use this widget area you need to enable the sidebar from Theme Manager&acute;s Manage Sidebar option.', 'threestar_setup' ),
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h2 class="widget-title">',
	'after_title' => '</h2>',
	) );
	register_sidebar( array(
	'name' => __( 'ThreeStar Footer Widget Area Three', 'threestar'),
	'id' => 'threestarfooterwidget3',
	'description' => __( 'Note: In order to use this widget area you need to enable the sidebar from Theme Manager&acute;s Manage Sidebar option.', 'threestar_setup' ),
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h2 class="widget-title">',
	'after_title' => '</h2>',
	) );
	register_sidebar( array(
	'name' => __( 'ThreeStar Footer Below Content Widget Area', 'threestar'),
	'id' => 'threestarfooterwidget4',
	'description' => __( 'An optional widget area for your site footer', 'threestar_setup' ),
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h3 class="widget-title">',
	'after_title' => '</h3>',
	) );
	register_sidebar( array(
	'name' => __( 'ThreeStar Footer Widget Bottom Area', 'threestar'),
	'id' => 'threestarfooterwidget5',
	'description' => __( 'An optional widget area for your site footer', 'threestar_setup' ),
	'before_widget' => '<div id="%1$s" class="widget %2$s">',
	'after_widget' => '</div>',
	'before_title' => '<h2 class="widget-title">',
	'after_title' => '</h2>',
	) );
}
add_action( 'widgets_init', 'threestar_widgets_init' );

if ( ! function_exists( 'threestar_paging_nav' ) ) :
/*** Displays navigation to next/previous set of posts when applicable. ***/
function threestar_paging_nav() {
	global $wp_query;

	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
	<nav class="navigation paging-navigation" role="navigation">
		<div class="nav-links">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'threestar' ) ); ?></div>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'threestar' ) ); ?></div>
			<?php endif; ?>

		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'threestar_post_nav' ) ) :
/*** Displays navigation to next/previous post when applicable. ***/
function threestar_post_nav() {
	global $post;

	// Don't print empty markup if there's nowhere to navigate.
	$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
	$next     = get_adjacent_post( false, '', false );

	if ( ! $next && ! $previous )
		return;
	?>
	<nav class="navigation post-navigation" role="navigation">
		<div class="nav-links">
			<div class="nav-previous-post"><?php previous_post_link( '%link', _x( '<span class="meta-nav"></span> %title', 'Previous post link', 'threestar' ) ); ?></div>
			<div class="nav-next-post"><?php next_post_link( '%link', _x( '%title <span class="meta-nav"></span>', 'Next post link', 'threestar' ) ); ?></div>
		</div><!-- .nav-links -->
	</nav><!-- .navigation -->
	<?php
}
endif;

if ( ! function_exists( 'threestar_entry_meta' ) ) :
/*** Prints HTML with meta information for current post: categories, tags, permalink, author, and date. ***/
function threestar_entry_meta() {
	if ( is_sticky() && is_home() && ! is_paged() )
		echo '<span class="featured-post">' . __( 'Sticky', 'threestar' ) . '</span>';

	if ( ! has_post_format( 'link' ) && 'post' == get_post_type() )
		threestar_entry_date();

	// Translators: used between list items, there is a space after the comma.
	$categories_list = get_the_category_list( __( ', ', 'threestar' ) );
	if ( $categories_list ) {
		echo '<span class="categories-links">' . $categories_list . '</span>';
	}

	// Post author
	if ( 'post' == get_post_type() ) {
		printf( '<span class="author"><a class="url fn n" href="%1$s" title="%2$s" rel="author">%3$s</a></span>',
			esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ),
			esc_attr( sprintf( __( 'View all posts by %s', 'threestar' ), get_the_author() ) ),
			get_the_author()
		);
	}

}
endif;

if ( ! function_exists( 'threestar_entry_date' ) ) :
/*** Prints HTML with date information for current post. ***/
function threestar_entry_date( $echo = true ) {
	if ( has_post_format( array( 'chat', 'status' ) ) )
		$format_prefix = _x( '%1$s on %2$s', '1: post format name. 2: date', 'threestar' );
	else
		$format_prefix = '%2$s';

	$date = sprintf( '<span class="date"><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date" datetime="%3$s">%4$s</time></a></span>',
		esc_url( get_permalink() ),
		esc_attr( sprintf( __( 'Permalink to %s', 'threestar' ), the_title_attribute( 'echo=0' ) ) ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( sprintf( $format_prefix, get_post_format_string( get_post_format() ), get_the_date() ) )
	);

	if ( $echo )
		echo $date;

	return $date;
}
endif;

if ( ! function_exists( 'threestar_the_attached_image' ) ) :
/*** Prints the attached image with a link to the next attached image. ***/
function threestar_the_attached_image() {
	$post                = get_post();
	$attachment_size     = apply_filters( 'threestar_attachment_size', array( 724, 724 ) );
	$next_attachment_url = wp_get_attachment_url();

	/*** Grab the IDs of all the image attachments in a gallery so we can get the URL of the next adjacent image in a gallery, or the first image (if we're
	 looking at the last image in a gallery), or, in a gallery of one, just the link to that image file. ***/
	$attachment_ids = get_posts( array(
		'post_parent'    => $post->post_parent,
		'fields'         => 'ids',
		'numberposts'    => -1,
		'post_status'    => 'inherit',
		'post_type'      => 'attachment',
		'post_mime_type' => 'image',
		'order'          => 'ASC',
		'orderby'        => 'menu_order ID'
	) );

	// If there is more than 1 attachment in a gallery...
	if ( count( $attachment_ids ) > 1 ) {
		foreach ( $attachment_ids as $attachment_id ) {
			if ( $attachment_id == $post->ID ) {
				$next_id = current( $attachment_ids );
				break;
			}
		}

		// get the URL of the next image attachment...
		if ( $next_id )
			$next_attachment_url = get_attachment_link( $next_id );

		// or get the URL of the first image attachment.
		else
			$next_attachment_url = get_attachment_link( array_shift( $attachment_ids ) );
	}

	printf( '<a href="%1$s" title="%2$s" rel="attachment">%3$s</a>',
		esc_url( $next_attachment_url ),
		the_title_attribute( array( 'echo' => false ) ),
		wp_get_attachment_image( $post->ID, $attachment_size )
	);
}
endif;

/*** Returns the URL from the post. ***/
function threestar_get_link_url() {
	$content = get_the_content();
	$has_url = get_url_in_content( $content );

	return ( $has_url ) ? $has_url : apply_filters( 'the_permalink', get_permalink() );
}


/*** Adjusts content_width value for video post formats and attachment templates. ***/
function threestar_content_width() {
	global $content_width;

	if ( is_attachment() )
		$content_width = 724;
	elseif ( has_post_format( 'audio' ) )
		$content_width = 484;
}
add_action( 'template_redirect', 'threestar_content_width' );

/*** Extends the default WordPress body classes. ***/
function threestar_body_class( $classes ) {
	if ( ! is_multi_author() )
		$classes[] = 'single-author';

	if ( ! get_option( 'show_avatars' ) )
		$classes[] = 'no-avatars';

	return $classes;
}
add_filter( 'body_class', 'threestar_body_class' );

/*** Add postMessage support for site title and description for the Customizer. ***/
function threestar_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
}
add_action( 'customize_register', 'threestar_customize_register' );

/*** Binds JavaScript handlers to make Customizer preview reload changes asynchronously.***/
function threestar_customize_preview_js() {
	wp_enqueue_script( 'threestar-customizer', get_template_directory_uri() . '/js/theme-customizer.js', array( 'customize-preview' ), '20130226', true );
}
add_action( 'customize_preview_init', 'threestar_customize_preview_js' );


//session code for three star
function threestarStartSession() {
    if(!session_id()) {
        session_start();
    }
}
add_action('init', 'threestarStartSession', 1);

//load all the plugins for three star
function threestar_load_plugin() {
	if (!class_exists('Function')) {
 		include_once(TEMPLATEPATH.'/inc/admin/theme-manager.php');
		if(!function_exists('wp_pagenavi')){
			include_once(TEMPLATEPATH.'/inc/wp-pagenavi/wp-pagenavi.php');
		}
		include_once(TEMPLATEPATH.'/inc/newsletter-widget.php');
		include_once(TEMPLATEPATH.'/inc/footer-widgets.php');
	}
}
add_action('after_setup_theme', 'threestar_load_plugin');

//activate the pagenavi on three star
function threestar_pagenavi_activation_status()
{
	/*page navi activation*/
}
register_activation_hook( __FILE__, 'threestar_pagenavi_activation_status' );

//custom menu create code for three star
function threestar_custom_menu()
{
	$custom_menu=wp_get_nav_menu_items('threestar_primary');
	$custom_menu_size=sizeof($custom_menu);
	update_option('slider_status', 'Enabled');
	
	if($custom_menu_size==0 || $custom_menu_size==1)
	{
		global $wpdb;
		wp_insert_term( 'threestar_primary', 'nav_menu'); 

		for($i=0;$i<$custom_menu_size;$i++)
		{
			if($custom_menu[$i]->title!="Home")
			{
				$menu3 = wp_get_nav_menu_object("threestar_primary");
				$menuID3 = (int) $menu3->term_id;
				$itemData3 = array(	 'menu-item-db-id' => 0,
				'menu-item-object-id' => 1,
				'menu-item-object' => 'post',
				'menu-item-type' => 'custom',
				'menu-item-parent-id' => 0,
				'menu-item-position' => 0,
				'menu-item-title' => 'Home',
				'menu-item-url' => site_url(),
				'menu-item-description' => $pageData['post_content'],
				'menu-item-attr-title' => $pageData['post_excerpt'],
				'menu-item-status' => 'publish',
				'menu-item-target' => ''
				);
				
				$thisMenuItem3 = wp_update_nav_menu_item($menuID3, 0, $itemData3);
				$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem3, "term_taxonomy_id" => $menuID3), array("%d", "%d"));
			}
		}
	}
	
	//custom homepage code
	$sitepath=get_template_directory_uri();
	global $wpdb;
	$gethomestatus=$wpdb->get_results("SELECT * FROM $wpdb->posts WHERE `id`='".get_option('threestar_home_page_id')."' ");
	$homestatus;
	foreach($gethomestatus as $gethmst)
	{
			$homestatus=$gethmst->post_status;
	}
	
	if(!get_option('threestar_home_page_id') || $homestatus=='trash')
	{
		$homepage = array(
			'post_title' => 'Home',
			'post_content' => '<div class="row feature-box-row"><div class="columns large-12 feature-box-inner"><div class="row"><div class="columns large-4 small-4 feature-img pr20"> <a href="#"><img src="'.$sitepath.'/images/fresh-parsley.jpg"/></a> <h4><a href="#">Search engine optimization</a></h4><p> Dis! Amet, aliquam ultricies ultricies in pellentesque est dictumst risus placerat nec, ac ac sed, ridiculus tincidunt, nec. </p><center><a href="#" class="morebutton">read more</a></center></div><div class="columns large-4 small-4 feature-img pr20"> <a href="#"><img src="'.$sitepath.'/images/fresh-parsley.jpg"/></a><h4><a href="#">Search engine optimization</a></h4><p> Dis! Amet, aliquam ultricies ultricies in pellentesque est dictumst risus placerat nec, ac ac sed, ridiculus tincidunt, nec.</p><center><a href="#" class="morebutton">read more</a></center></div><div class="columns large-4 small-4 feature-img"> <a href="#"><img src="'.$sitepath.'/images/fresh-parsley.jpg"/></a> <h4><a href="#">Search engine optimization</a></h4><p> Dis! Amet, aliquam ultricies ultricies in pellentesque est dictumst risus placerat nec, ac ac sed, ridiculus tincidunt, nec. </p><center><a href="#" class="morebutton">read more</a></center></div></div></div></div><div class="row service-box-row"><div class="columns large-12 service-box-inner"><div class="row"><div class="columns large-12 service-img pr20"><h3 class="title">Checkout Our Services</h3><p> Dis! Amet, aliquam ultricies ultricies in cras pellentesque est dictumst risus placerat est nec, ac ac sed, ridiculus tincidunt, nec. Lacus, risus aliquet lacus Dis Amet, aliquam ultricies ultricies in cras pellentesque est dictumst risus placerat est nec, ac ac sed, ridiculus tincidunt, nec. Lacus, risus aliquet lacus Dis! Amet, aliquam ultricies ultricies in cras pellentesque est dictumst risus placerat est nec, ac ac sed, ridiculus tincidunt, nec. Lacus, risus aliquet lacus Dis! Amet, aliquam ultricies ultricies in cras pellentesque est dictumst risus placerat est nec, ac ac sed, ridiculus tincidunt, nec. Lacus, risus aliquet lacus </p></div></div><div class="row"><div class="columns large-4 feature-img pr20"> <h4><a href="#">Search engine optimization</a></h4><ul class="bullet service-benefits-list"><li>ed do eiusmod tempor incididunt ut doloremque</li><li>At vero eos et accusamus et iusto laudantium</li><li>Itaque earum rerum tenetu sapiente accusamus</li><li>ed do eiusmod tempor incididunt ut do eiusmod</li><li>At vero eos et accusamus et iusto accusamus</li><li>Itaque earum rerum tenetu sapiente rerum vero</li></ul><a class="button callToAction">Get Free Qoutation</a> </div><div class="columns large-4 feature-img pr20"> <h4><a href="#">Search engine optimization</a></h4><ul class="bullet service-benefits-list"><li>ed do eiusmod tempor incididunt ut doloremque</li><li>At vero eos et accusamus et iusto laudantium</li><li>Itaque earum rerum tenetu sapiente accusamus</li><li>ed do eiusmod tempor incididunt ut do eiusmod</li><li>At vero eos et accusamus et iusto accusamus</li> <li>Itaque earum rerum tenetu sapiente rerum vero</li></ul><a class="button callToAction">Get Free Qoutation</a> </div><div class="columns large-4 feature-img"><h4><a href="#">Search engine optimization</a></h4><ul class="bullet service-benefits-list"><li>ed do eiusmod tempor incididunt ut doloremque</li><li>At vero eos et accusamus et iusto laudantium</li><li>Itaque earum rerum tenetu sapiente accusamus</li><li>ed do eiusmod tempor incididunt ut do eiusmod</li><li>At vero eos et accusamus et iusto accusamus</li><li>Itaque earum rerum tenetu sapiente rerum vero</li></ul><a class="button callToAction">Get Free Qoutation</a> </div></div></div></div>',
			'post_status'   => 'publish',
			'post_type'   => 'page',
			'post_author'   => 1
		);
			$home_page_id=wp_insert_post( $homepage );
			update_option('threestar_home_page_id', $home_page_id);
	}
	
	threestar_add_theme_options();
}
add_action("after_switch_theme", "threestar_custom_menu");



//three star theme options configuration
function threestar_add_theme_options()
{	
	
/*** The code for adding demo data starts here ***/	
$sitepath=get_template_directory_uri();

//slider code
$slider1=array('image'=>$sitepath.'/images/slide.jpg', 'link'=>$sitepath.'/images/slide.jpg');
update_option('slider_image1', $slider1);

$slider2=array('image'=>$sitepath.'/images/slide.jpg', 'link'=>$sitepath.'/images/slide.jpg');
update_option('slider_image2', $slider2);


$slider3=array('image'=>$sitepath.'/images/slide.jpg', 'link'=>$sitepath.'/images/slide.jpg');
update_option('slider_image3', $slider3);

$slider4=array('image'=>$sitepath.'/images/slide.jpg', 'link'=>$sitepath.'/images/slide.jpg');
update_option('slider_image4', $slider4);

$slider5=array('image'=>$sitepath.'/images/slide.jpg', 'link'=>$sitepath.'/images/slide.jpg');
update_option('slider_image5', $slider5);

update_option('slider_status', 'Enabled');
	
//contact details code
$contact_data=array('company_name'=>'3 Star', 'address'=>'255, WILLSON STREET, CAULFIELD', 'city'=>'MELBOURNE', 'zip'=>'2211', 'state'=>'Victoria', 'contact_number'=>'1800-900-800', 'contact_number2'=>'1800-560-660', 'contact_number3'=>'1800-726-192','mobile'=>'(342)908898','fax'=>'(132)1239040', 'email'=>'BIZ_AMY@YAHOO.COM', 'country'=>'Australia');
update_option('contact_data', $contact_data);

//map details
$latitude = '-37.907808';
update_option('latitude', $latitude);

$longitude = '145.093862';
update_option('longitude', $longitude);

update_option('map_name', '3 Star');
	
//captcha status
update_option('captcha_status', 'Enabled');
	
//mail messages
update_option('mail_error_msg', 'There was some problem sending the mail this time. Please try again.');
update_option('mail_success_msg', 'Mail Sent Successfully. We will get back to you asap. Thanks for your query.');
	
//social media code
update_option('twitter_link', 'http://twitter.com/');
update_option('facebook_link', 'http://www.facebook.com/');
update_option('youtube_link', 'http://www.youtube.com/');
update_option('reddit_link', 'http://www.reddit.com/');
		
//newsletter form
update_option('newsletter_link', 'http://wpforest.us4.list-manage.com/subscribe/post?u=2968811dff1cd9c6b2641a0b0&amp;id=4c5eb8d66b');

//custom css
update_option('threestar_custom_user_css','');

//sidebar status code
update_option('threestar_sidebar_status','Disabled');
update_option('threestar_theme_options_status', 'active');

//slider right text
$slider_right_content=array('title'=>'PROFESSIONAL AND BEST FEATURES', 'sub-title'=>'Get Your Business Online Presence','description'=>'Amet sagittis aliquam non parturient magnis porttitor cum scelerisque magna in,turpis integer! Nunc, porta, ultricies aliquam turpis sociis in sociis mus.Amet sagittis aliquam non parturient magnis porttitor cum scelerisque magna in, turpis integer! Nunc, porta, ultricies aliquam tu sociis in velit sociis mus Amet sagittis aliquam non parturient magnis porttitor cum scelerisque magna in, turpis integer! Nunc, porta, ultricie aliquam turpis sociis in velit sociis mus', 'tour_button_text'=>'Take A Demo Tour','tour_button_link'=>'#');
update_option('slider_right_content', $slider_right_content);


	
/*** The code for adding demo data ends here ***/	

}

//three star theme deactivation options
function threestar_deactivation() {
	delete_option('latitude');
	delete_option('longitude');
	delete_option('map_name');
	delete_option('captcha_status');
	delete_option('SMTP Host');
	delete_option('Port');
	delete_option('Mail Username');
	delete_option('Mail Password');
	delete_option('twitter_link');
	delete_option('facebook_link');
	delete_option('youtube_link');
	delete_option('reddit_link');
}

//three star page creation code
function threestar_create_pages()
{
	global $wpdb;
	$imgpath=get_template_directory_uri();

	//Demo About Page
	$getaboutstatus=$wpdb->get_results("SELECT * FROM $wpdb->posts WHERE `id`='".get_option('threestar_about_us_page_id')."' ");
	$aboutstatus;
	foreach($getaboutstatus as $getabst)
	{
			$aboutstatus=$getabst->post_status;
	}
	if(!get_option('threestar_about_us_page_id') || $aboutstatus=='trash')
	{
			$about_page = array(
			  'post_title'    => 'About Us',
			  'post_content'  => '<div class="columns large-12 content-inner"><div class="row"><div class="columns large-12"><ul class="large-block-grid-3"><li><div class="img-wrapper"><img class="about-image" src="'.$imgpath.'/images/redwoman.jpg"/></div><h3 class="employer-name">Rebecca Traver</h3><p>Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem</p></li><li><div class="img-wrapper"><img class="about-image" src="'.$imgpath.'/images/man.jpg"/></div><h3 class="employer-name">NATHELIAN CHRISTMAS</h3><p>Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat volupt porro atem</p></li><li><div class="img-wrapper"><img class="about-image" src="'.$imgpath.'/images/youngwoman.jpg"/></div><h3 class="employer-name">Shamitha S Rao</h3><p>Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem</p></li></ul></div></div><div class="row testimonial">[column_one_fourth] <img class="test-img" src="'.$imgpath.'/images/mantest.jpg"/> [/column_one_fourth]<div class="columns large-9"><p class="testimoial-text"> Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem </p><p class="testimonial-credits"><b>Raghveer, Senior Consultant, BWR Pvt Ltd.</b></p></div></div></div>',
			  'post_status'   => 'publish',
			  'post_type'   => 'page',
			  'post_author'   => 1
			);
			
			$about_page_id=wp_insert_post( $about_page );
			update_post_meta($about_page_id, 'page_sub_title', 'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis');
			update_option('threestar_about_us_page_id', $about_page_id);
	}
		
	//About us code ends	
	
	//Demo Gallery Page
	$getgallerystatus=$wpdb->get_results("SELECT * FROM $wpdb->posts WHERE `id`='".get_option('threestar_gallery_page_id')."' ");
	$gallerystatus;
	foreach($getgallerystatus as $getglst)
	{
			$gallerystatus=$getglst->post_status;
	}
	
	if(!get_option('threestar_gallery_page_id') || $gallerystatus=='trash')
	{
		$gallery_page = array(
		  'post_title'    => 'Gallery',
		  'post_content'  => '<div class="columns large-12 content-inner"><div class="row  gallery-block"><p><strong>Image Gallery</strong></p><hr />[3star_gallery][img imagelink="'.$imgpath.'/images/baby-lamb.jpg"][img imagelink="'.$imgpath.'/images/golden-wheat-field.jpg"][img imagelink="'.$imgpath.'/images/cracked-earth-texture.jpg"][img imagelink="'.$imgpath.'/images/beautiful-young-girl.jpg"][img imagelink="'.$imgpath.'/images/tree-and-storm-2.jpg"][img imagelink="'.$imgpath.'/images/trees.jpg"][img imagelink="'.$imgpath.'/images/coffee.jpg"][img imagelink="'.$imgpath.'/images/house.jpg"][/3star_gallery]<p><strong>Video Gallery</strong></p><hr />[3star_gallery][3star_video image="'.$imgpath.'/images/video-image-demo.gif" videolink="http://www.youtube.com/embed/VOJyrQa_WR4?rel=0&amp;wmode=transparent"][3star_video image="'.$imgpath.'/images/video-image-demo.gif" videolink="http://www.youtube.com/embed/_E1UxI5I_jo?rel=0&amp;wmode=transparent"][3star_video image="'.$imgpath.'/images/video-image-demo.gif" videolink="http://www.youtube.com/embed/Zxk_WywMTzc?rel=0&amp;wmode=transparent"][3star_video image="'.$imgpath.'/images/video-image-demo.gif" videolink="http://www.youtube.com/embed/-Xy_Is1lUZo?rel=0&amp;wmode=transparent"][/3star_gallery]</div><div class="row"><div><p>Augue, in lectus? Velit rhoncus. Nec! Porttitor ultrices, magna, lacus porttitor egestas et sit aliquet aliquet. Pulvinar rhoncus! Odio egestas? Ultrices velit ultricies hac, est aenean habitasse habitasse, nec, integer magna montes porttitor phasellus</p></div></div></div>',
		  'post_status'   => 'publish',
		  'post_type'   =>   'page',
		  'post_author'   => 1
		);
		
		$gallery_page_id=wp_insert_post( $gallery_page );
		update_post_meta($gallery_page_id, 'page_sub_title', 'Augue, in lectus? Velit rhoncus. Nec! Porttitor ultrices, magna, lacus porttitor egestas et sit aliquet aliquet. Pulvinar rhoncus! Odio egestas? Ultrices velit ultricies hac, est aenean habitasse habitasse, nec, integer magna montes porttitor phasellus');
		update_option('threestar_gallery_page_id', $gallery_page_id);
	
	}
	//Gallery code ends	
	
	//Demo Contact Page
	$getcontactstatus=$wpdb->get_results("SELECT * FROM $wpdb->posts WHERE `id`='".get_option('threestar_contact_page_id')."' ");
	$contactstatus;
	foreach($getcontactstatus as $getcntst)
	{
			$contactstatus=$getcntst->post_status;
	}
	if(!get_option('threestar_contact_page_id') || $contactstatus=='trash')
	{
		$contact_page = array(
		  'post_title'    => 'Contact Us',
		  'post_content'  => '[threestar-contact-page]',
		  'post_status'   => 'publish',
		  'post_type'   => 'page',
		  'post_author'   => 1,
		);
		
		$contact_page_id=wp_insert_post( $contact_page );
		update_post_meta( $contact_page_id, '_wp_page_template', 'contact.php' );
		update_option('threestar_contact_page_id', $contact_page_id);
	}
	//Contact code ends
	
	//Demo Services Page
	$getservicesstatus=$wpdb->get_results("SELECT * FROM $wpdb->posts WHERE `id`='".get_option('threestar_services_page_id')."' ");
	$servicesstatus;
	foreach($getservicesstatus as $getsrvcst)
	{
			$servicesstatus=$getsrvcst->post_status;
	}
	if(!get_option('threestar_services_page_id') || $servicesstatus=='trash')
	{

		$services_page = array(
		  'post_title'    => 'Services',
		  'post_content'  => '<div class="columns large-12 content-inner"><div class="row services">[column_one_fourth] <img class="services-image" src="'.$imgpath.'/images/fresh-parsley.jpg"/> [/column_one_fourth]<div class="columns large-9"><h3 class="service-title">Service Title One</h3><p> Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repella Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem </p></div></div><div class="row services"><div class="columns large-9"><h3 class="service-title">Service Title Two</h3><p> Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repella Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem </p></div>[column_one_fourth] <img class="services-image right" src="'.$imgpath.'/images/cup1.jpg"/> [/column_one_fourth]</div><div class="row services">[column_one_fourth] <img class="services-image " src="'.$imgpath.'/images/cup.jpg"/>[/column_one_fourth]<div class="columns large-9"><h3 class="service-title">Service Title Three</h3><p> Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repella Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem </p></div></div><div class="row services"><div class="columns large-9"><h3 class="service-title">Service Title Four</h3><p> Temporibus autem quibusdam et aut officiis debitis aut rerum necessitatibus saepe eveniet ut et voluptates repudiandae sint et molestiae non recusandae. Itaque earum rerum hic tenetur a sapiente delectus, ut aut reiciendis voluptatibus maiores alias consequatur aut perferendis doloribus asperiores repella  Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat voluptatem </p></div>[column_one_fourth] <img class="services-image right" src="'.$imgpath.'/images/fresh-parsley.jpg"/> [/column_one_fourth]</div></div>',
		  'post_status'   => 'publish',
		  'post_type'   => 'page',
		  'post_author'   => 1
		);
		
		$services_page_id=wp_insert_post( $services_page );
		update_post_meta($services_page_id, 'page_sub_title', 'Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis');
		update_option('threestar_services_page_id', $services_page_id);
	}
	//Services code ends	
	
	//Demo Testimonials Page
	$gettestimonialstatus=$wpdb->get_results("SELECT * FROM $wpdb->posts WHERE `id`='".get_option('threestar_testimonial_page_id')."' ");
	$testimonialstatus;
	foreach($gettestimonialstatus as $gettestist)
	{
			$testimonialstatus=$gettestist->post_status;
	}
	if(!get_option('threestar_testimonial_page_id') || $servicesstatus=='trash')
	{

		$testimonial_page = array(
		  'post_title'    => 'Testimonials',
		  'post_content'  => '<div class="columns large-12  content-inner"><div class="row testimonial">[column_one_fourth] <img class="test-img" src="'.$imgpath.'/images/mantest.jpg"/>[/column_one_fourth]<div class="columns large-9"><p class="testimoial-text"> Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem </p><p class="testimonial-credits"><b>Raghveer, Senior Consultant, BWR Pvt Ltd.</b></p></div></div><div class="row testimonial">[column_one_fourth] <img class="test-img" src="'.$imgpath.'/images/man.jpg"/>[/column_one_fourth]<div class="columns large-9"><p class="testimoial-text"> Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem </p><p class="testimonial-credits"><b>Vishnu Dutt, Manager, YPS Systems.</b></p></div></div><div class="row testimonial">[column_one_fourth] <img class="test-img" src="'.$imgpath.'/images/mantest.jpg"/>[/column_one_fourth]<div class="columns large-9"><p class="testimoial-text"> Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem </p><p class="testimonial-credits"><b>Raghveer, Senior Consultant, BWR Pvt Ltd.</b></p></div></div><div class="row testimonial">[column_one_fourth] <img class="test-img" src="'.$imgpath.'/images/man.jpg"/>[/column_one_fourth]<div class="columns large-9"><p class="testimoial-text"> Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem Neque porro quisquam est, qui dolorem ipsum quia dolor sit amet, consectetur, adipisci velit, sed quia non numquam eius modi tempora incidunt ut labore et dolore magnam aliquam quaerat porro voluptatem </p><p class="testimonial-credits"><b>Vishnu Dutt, Manager, YPS Systems.</b></p></div></div></div>',
		  'post_status'   => 'publish',
		  'post_type'   => 'page',
		  'post_author'   => 1
		);
		
		$testimonial_page_id=wp_insert_post( $testimonial_page );
		update_post_meta( $testimonial_page_id, '_wp_page_template', 'testimonials.php' );
		update_option('threestar_testimonial_page_id', $testimonial_page_id);
	}
	//Testimonials code ends

	
	$wpdb->query("DELETE FROM $wpdb->terms WHERE `name`='threestar_primary' ");
	
	wp_insert_term( 'threestar_primary', 'nav_menu'); //adds top menus
	wp_insert_term( 'Blog', 'category'); 
	
	$blogcatid;
	$gblid=$wpdb->get_results("SELECT * FROM $wpdb->terms WHERE `name`='Blog' ");
	foreach($gblid as $gbl)
	{
		$blogcatid=$gbl->term_id;
	}
	
	register_nav_menus( array(  
	'primary' => __( 'threestar_primary', 'threestar' ),  
	) );
	
	//path for featured image
	$image_url=get_template_directory_uri().'/images/demo-featured-image.jpg';
	$upload_dir = wp_upload_dir();
	$filename = basename($image_url);
	if(wp_mkdir_p($upload_dir['path']))
		$file = $upload_dir['path'] . '/' . $filename;
	else
		$file = $upload_dir['basedir'] . '/' . $filename;
	move_uploaded_file($image_url, $file);
	
	$wp_filetype = wp_check_filetype($filename, null );
	$attachment = array(
		'post_mime_type' => $wp_filetype['type'],
		'post_title' => sanitize_file_name($filename),
		'post_content' => '',
		'post_status' => 'inherit'
	);
	$attach_id = wp_insert_attachment( $attachment, $file, $post_id );
	require_once(ABSPATH . 'wp-admin/includes/image.php');
	$attach_data = wp_generate_attachment_metadata( $attach_id, $file );
	wp_update_attachment_metadata( $attach_id, $attach_data );
	
	//create demo posts
	if(!get_option('threestar_demo_post1'))
	{
		$demo_post1 = array(
		  'post_title'    => 'Demo Post 1',
		  'post_content'  => '<div class="columns large-12"><p>Egestas aliquam vel ultrices integer, ut sit pellentesque, et montes, turpis phasellus mauris porta parturient platea pulvinar risus, lectus? Pid! Elementum sociis nunc sit! Dolor in eu ut placerat pellentesque, platea est risus etiam, dolor! Nec, penatibus odio scelerisque elementum pulvinar urna, dis nec vel nunc ut mid! In eros magna vel urna a platea proin, in tortor ultricies, et egestas amet, pellentesque ac, sit est ac integer ut cum porttitor penatibus, sed purus odio! Mauris nec? Quis, facilisis, tempor magna in vel lacus, cras risus, vel montes penatibus ultrices, aenean penatibus, nec lectus lacus penatibus? Egestas duis. Diam phasellus, integer in etiam sociis porta turpis proin in? Ridiculus! Turpis mauris placerat. Tincidunt in scelerisque diam mus egestas? Augue mauris. Augue etiam. Porta? Cum sed platea, nunc elit ultricies phasellus auctor augue aliquam tempor. Amet velit, adipiscing sed ac dictumst penatibus aliquam, parturient, purus. Enim nec augue mauris elementum cras.</p><!--more--><p>Dolor amet amet lectus phasellus, dolor aliquam. Nascetur arcu urna placerat, mid, elit adipiscing parturient nec ac dolor amet. Velit? Augue enim nisi phasellus velit, sit nunc elit natoque lacus, mus et ac vut mattis? Eu pulvinar pulvinar et, in habitasse, lundium, ridiculus? Arcu, ultrices, amet augue, ac pulvinar urna cum, turpis pid, eu. Ac porttitor, ut aliquam in? Ridiculus ac. Urna augue pid tortor porttitor vut, amet, enim ut turpis, sociis dignissim, augue sit porta scelerisque, in lectus aliquam vut habitasse ac? Rhoncus, placerat! Eros nec tincidunt ultrices scelerisque lorem. Sed diam mauris diam egestas? Amet in, mauris, nunc sociis scelerisque, sed eu, et mus, pulvinar, velit et facilisis lacus a aliquam non ut, sit porta? Diam ultricies? Placerat ut auctor urna adipiscing sit, quis rhoncus pulvinar integer sed proin? Porta penatibus magna, elementum, lorem nisi, elit adipiscing, mauris, porta egestas pid, vut sed arcu tristique, rhoncus sit.</p></div>',
		  'post_status'   => 'publish',
		  'post_type'   => 'post',
		  'post_author'   => 1,
		  'post_thumbnail' => $featured_img_path,
		  'post_category' => array($blogcatid)
		);
	
		$threestar_demo_post1=wp_insert_post( $demo_post1 );	
		update_option('threestar_demo_post1', $threestar_demo_post1);
		set_post_thumbnail( $threestar_demo_post1, $attach_id );

	}
	
	
	if(!get_option('threestar_demo_post2'))
	{
		$demo_post2 = array(
		  'post_title'    => 'Demo Post 2',
		  'post_content'  => '<div class="columns large-12"><p>Egestas aliquam vel ultrices integer, ut sit pellentesque, et montes, turpis phasellus mauris porta parturient platea pulvinar risus, lectus? Pid! Elementum sociis nunc sit! Dolor in eu ut placerat pellentesque, platea est risus etiam, dolor! Nec, penatibus odio scelerisque elementum pulvinar urna, dis nec vel nunc ut mid! In eros magna vel urna a platea proin, in tortor ultricies, et egestas amet, pellentesque ac, sit est ac integer ut cum porttitor penatibus, sed purus odio! Mauris nec? Quis, facilisis, tempor magna in vel lacus, cras risus, vel montes penatibus ultrices, aenean penatibus, nec lectus lacus penatibus? Egestas duis. Diam phasellus, integer in etiam sociis porta turpis proin in? Ridiculus! Turpis mauris placerat. Tincidunt in scelerisque diam mus egestas? Augue mauris. Augue etiam. Porta? Cum sed platea, nunc elit ultricies phasellus auctor augue aliquam tempor. Amet velit, adipiscing sed ac dictumst penatibus aliquam, parturient, purus. Enim nec augue mauris elementum cras.</p><!--more--><p>Dolor amet amet lectus phasellus, dolor aliquam. Nascetur arcu urna placerat, mid, elit adipiscing parturient nec ac dolor amet. Velit? Augue enim nisi phasellus velit, sit nunc elit natoque lacus, mus et ac vut mattis? Eu pulvinar pulvinar et, in habitasse, lundium, ridiculus? Arcu, ultrices, amet augue, ac pulvinar urna cum, turpis pid, eu. Ac porttitor, ut aliquam in? Ridiculus ac. Urna augue pid tortor porttitor vut, amet, enim ut turpis, sociis dignissim, augue sit porta scelerisque, in lectus aliquam vut habitasse ac? Rhoncus, placerat! Eros nec tincidunt ultrices scelerisque lorem. Sed diam mauris diam egestas? Amet in, mauris, nunc sociis scelerisque, sed eu, et mus, pulvinar, velit et facilisis lacus a aliquam non ut, sit porta? Diam ultricies? Placerat ut auctor urna adipiscing sit, quis rhoncus pulvinar integer sed proin? Porta penatibus magna, elementum, lorem nisi, elit adipiscing, mauris, porta egestas pid, vut sed arcu tristique, rhoncus sit.</p></div>',
		  'post_status'   => 'publish',
		  'post_type'   => 'post',
		  'post_author'   => 1,
		   'post_thumbnail' => $featured_img_path,
		  'post_category' => array($blogcatid)
		);
		
		$threestar_demo_post2=wp_insert_post( $demo_post2 );
		update_option('threestar_demo_post2', $threestar_demo_post2);
		set_post_thumbnail( $threestar_demo_post2, $attach_id );
	}
	
	if(!get_option('threestar_demo_post3'))
	{
		$demo_post3 = array(
		  'post_title'    => 'Demo Post 3',
		  'post_content'  => '<div class="columns large-12"><p>Egestas aliquam vel ultrices integer, ut sit pellentesque, et montes, turpis phasellus mauris porta parturient platea pulvinar risus, lectus? Pid! Elementum sociis nunc sit! Dolor in eu ut placerat pellentesque, platea est risus etiam, dolor! Nec, penatibus odio scelerisque elementum pulvinar urna, dis nec vel nunc ut mid! In eros magna vel urna a platea proin, in tortor ultricies, et egestas amet, pellentesque ac, sit est ac integer ut cum porttitor penatibus, sed purus odio! Mauris nec? Quis, facilisis, tempor magna in vel lacus, cras risus, vel montes penatibus ultrices, aenean penatibus, nec lectus lacus penatibus? Egestas duis. Diam phasellus, integer in etiam sociis porta turpis proin in? Ridiculus! Turpis mauris placerat. Tincidunt in scelerisque diam mus egestas? Augue mauris. Augue etiam. Porta? Cum sed platea, nunc elit ultricies phasellus auctor augue aliquam tempor. Amet velit, adipiscing sed ac dictumst penatibus aliquam, parturient, purus. Enim nec augue mauris elementum cras.</p><!--more--><p>Dolor amet amet lectus phasellus, dolor aliquam. Nascetur arcu urna placerat, mid, elit adipiscing parturient nec ac dolor amet. Velit? Augue enim nisi phasellus velit, sit nunc elit natoque lacus, mus et ac vut mattis? Eu pulvinar pulvinar et, in habitasse, lundium, ridiculus? Arcu, ultrices, amet augue, ac pulvinar urna cum, turpis pid, eu. Ac porttitor, ut aliquam in? Ridiculus ac. Urna augue pid tortor porttitor vut, amet, enim ut turpis, sociis dignissim, augue sit porta scelerisque, in lectus aliquam vut habitasse ac? Rhoncus, placerat! Eros nec tincidunt ultrices scelerisque lorem. Sed diam mauris diam egestas? Amet in, mauris, nunc sociis scelerisque, sed eu, et mus, pulvinar, velit et facilisis lacus a aliquam non ut, sit porta? Diam ultricies? Placerat ut auctor urna adipiscing sit, quis rhoncus pulvinar integer sed proin? Porta penatibus magna, elementum, lorem nisi, elit adipiscing, mauris, porta egestas pid, vut sed arcu tristique, rhoncus sit.</p></div>',
		  'post_status'   => 'publish',
		  'post_type'   => 'post',
		  'post_author'   => 1,
		  'post_thumbnail' => $featured_img_path,
		  'post_category' => array($blogcatid)
		);
		
		$threestar_demo_post3=wp_insert_post( $demo_post3 );
		update_option('threestar_demo_post3', $threestar_demo_post3);
		set_post_thumbnail( $threestar_demo_post3, $attach_id );
	}
	//demo posts ends
	
	/**********threestar_primary menu**********/
	
	//create menu item for home
	$menu = wp_get_nav_menu_object("threestar_primary");
	$menuID = (int) $menu->term_id;
	$itemData = array(	 'menu-item-db-id' => 0,
	'menu-item-object-id' => $pageId,
	'menu-item-object' => 'page',
	'menu-item-type' => 'custom',
	'menu-item-parent-id' => 0,
	'menu-item-position' => 0,
	'menu-item-title' => 'Home',
	'menu-item-url' => site_url(),
	'menu-item-description' => $pageData['post_content'],
	'menu-item-attr-title' => $pageData['post_excerpt'],
	'menu-item-status' => 'publish',
	'menu-item-target' => ''
	);
	$thisMenuItem = wp_update_nav_menu_item($menuID, 0, $itemData);
	$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem, "term_taxonomy_id" => $menuID), array("%d", "%d"));
	//menu item for home ends
	
	//create menu item for about us
	$menu = wp_get_nav_menu_object("threestar_primary");
	$menuID = (int) $menu->term_id;
	$pageId = get_option('threestar_about_us_page_id');
	$itemData = array(	 'menu-item-db-id' => 0,
	'menu-item-object-id' => $pageId,
	'menu-item-object' => 'page',
	'menu-item-type' => 'post_type',
	'menu-item-parent-id' => 0,
	'menu-item-position' => 2,
	'menu-item-title' => $pageData['title'],
	'menu-item-url' => get_permalink($pageId),
	'menu-item-description' => $pageData['post_content'],
	'menu-item-attr-title' => $pageData['post_excerpt'],
	'menu-item-status' => 'publish',
	'menu-item-target' => ''
	);
	$thisMenuItem = wp_update_nav_menu_item($menuID, 0, $itemData);
	$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem, "term_taxonomy_id" => $menuID), array("%d", "%d"));
	//menu item for aboout us ends

	//create menu item for gallery
	$menu = wp_get_nav_menu_object("threestar_primary");
	$menuID = (int) $menu->term_id;
	$pageId = get_option('threestar_gallery_page_id');
	$itemData = array(	 'menu-item-db-id' => 0,
	'menu-item-object-id' => $pageId,
	'menu-item-object' => 'page',
	'menu-item-type' => 'post_type',
	'menu-item-parent-id' => 0,
	'menu-item-position' => 4,
	'menu-item-title' => $pageData['title'],
	'menu-item-url' => get_permalink($pageId),
	'menu-item-description' => $pageData['post_content'],
	'menu-item-attr-title' => $pageData['post_excerpt'],
	'menu-item-status' => 'publish',
	'menu-item-target' => ''
	);
	$thisMenuItem = wp_update_nav_menu_item($menuID, 0, $itemData);
	$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem, "term_taxonomy_id" => $menuID), array("%d", "%d"));
	//menu item for gallery ends
	
	//create menu item for services
	$menu = wp_get_nav_menu_object("threestar_primary");
	$menuID = (int) $menu->term_id;
	$pageId = get_option('threestar_services_page_id');
	$itemData = array(	 'menu-item-db-id' => 0,
	'menu-item-object-id' => $pageId,
	'menu-item-object' => 'page',
	'menu-item-type' => 'post_type',
	'menu-item-parent-id' => 0,
	'menu-item-position' => 5,
	'menu-item-title' => $pageData['title'],
	'menu-item-url' => get_permalink($pageId),
	'menu-item-description' => $pageData['post_content'],
	'menu-item-attr-title' => $pageData['post_excerpt'],
	'menu-item-status' => 'publish',
	'menu-item-target' => ''
	);
	$thisMenuItem = wp_update_nav_menu_item($menuID, 0, $itemData);
	$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem, "term_taxonomy_id" => $menuID), array("%d", "%d"));
	//menu item for services ends
	
	//create menu item for testimonials
	$menu = wp_get_nav_menu_object("threestar_primary");
	$menuID = (int) $menu->term_id;
	$pageId = get_option('threestar_testimonial_page_id');
	$itemData = array(	 'menu-item-db-id' => 0,
	'menu-item-object-id' => $pageId,
	'menu-item-object' => 'page',
	'menu-item-type' => 'post_type',
	'menu-item-parent-id' => 0,
	'menu-item-position' => 6,
	'menu-item-title' => $pageData['title'],
	'menu-item-url' => get_permalink($pageId),
	'menu-item-description' => $pageData['post_content'],
	'menu-item-attr-title' => $pageData['post_excerpt'],
	'menu-item-status' => 'publish',
	'menu-item-target' => ''
	);
	$thisMenuItem = wp_update_nav_menu_item($menuID, 0, $itemData);
	$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem, "term_taxonomy_id" => $menuID), array("%d", "%d"));
	//menu item for testimonials ends
	
	//create menu item for contact us
	$menu = wp_get_nav_menu_object("threestar_primary");
	$menuID = (int) $menu->term_id;
	$pageId = get_option('threestar_contact_page_id');
	$itemData = array(	 'menu-item-db-id' => 0,
	'menu-item-object-id' => $pageId,
	'menu-item-object' => 'page',
	'menu-item-type' => 'post_type',
	'menu-item-parent-id' => 0,
	'menu-item-position' => 7,
	'menu-item-title' => $pageData['title'],
	'menu-item-url' => get_permalink($pageId),
	'menu-item-description' => $pageData['post_content'],
	'menu-item-attr-title' => $pageData['post_excerpt'],
	'menu-item-status' => 'publish',
	'menu-item-target' => ''
	);
	$thisMenuItem = wp_update_nav_menu_item($menuID, 0, $itemData);
	$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem, "term_taxonomy_id" => $menuID), array("%d", "%d"));
	//menu item for contact us ends
	
	/**********top menu ends**********/

	/**code for adding blog to nav menu**/
	$category_id = get_cat_ID( 'Blog' );
	$category_link = get_category_link( $category_id );

	$menu = wp_get_nav_menu_object("threestar_primary");
	$menuID = (int) $menu->term_id;
	$catId = $gb->term_id;
	$itemData = array(	 'menu-item-db-id' => 0,
	'menu-item-object-id' => $catId,
	'menu-item-object' => 'post',
	'menu-item-type' => 'custom',
	'menu-item-parent-id' => 0,
	'menu-item-position' => 3,
	'menu-item-title' => 'Blog',
	'menu-item-url' =>  $category_link,
	'menu-item-description' => $catData['post_content'],
	'menu-item-attr-title' => $catData['post_excerpt'],
	'menu-item-status' => 'publish',
	'menu-item-target' => ''
	);
	$thisMenuItem = wp_update_nav_menu_item($menuID, 0, $itemData);
	$wpdb->insert($wpdb->term_relationships, array("object_id" => $thisMenuItem, "term_taxonomy_id" => $menuID), array("%d", "%d"));
	/**code for adding blog to nav menu ends**/
	
}

function threestar_homepage_deactivation() {
	global $wpdb;
	$wpdb->query("DELETE FROM $wpdb->posts WHERE `ID`='".get_option('threestar_home_page_id')."' ");
 	delete_option('threestar_home_page_id');
}
add_action("switch_theme", "threestar_homepage_deactivation");

//contact form page
function threestar_get_contact_page_data($atts)
{	
?>
<div class="columns large-12 content-inner">
<div class="row contact-form">
  <div class="columns large-5">
    <div class="contact-img"><img src="<?php echo get_template_directory_uri();?>/images/company.jpg"/></div>
  </div>
  <div class="columns large-7">
    <form id="contact-form" method="post">
      <input type="text" name="name" placeholder="Name:"/>
      <input type="text" name="email" placeholder="Email:"/>
      <input type="text" name="subject" placeholder="Subject:"/>
      <textarea  name="message" id="message"></textarea>
      <?php 
	   		if(get_option('captcha_status')=='Enabled')
			{
				get_template_part('inc/captcha');
				$captcha = new Captcha();
				$captcha->showImage();
				$_SESSION['captcha'] = $captcha->getCode();
	  ?>
      <input type="text" name="captchaCode" placeholder="Enter the code below"/>
      <span class="captcha-img"><img src="<?php echo get_template_directory_uri();?>/images/captcha.jpg"/></span>
      <?php }//captcha check ends ?>
      <input type="submit" class="button send" name="submit" value="send"/>
    </form>
  </div>
</div>
<div class="row">
  <div class="columns large-12">
    <div id="map_canvas"></div>
  </div>
</div>
</div>
<?php
}
add_shortcode( 'threestar-contact-page', 'threestar_get_contact_page_data' );

//custom redirect function
function custom_redirect() 
{
	$url=admin_url()."themes.php?page=threestar-mgr";
	echo "<META HTTP-EQUIV='REFRESH' CONTENT='0;URL=$url'>";
}
function threestar_comment($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
     <div id="comment-<?php comment_ID(); ?>">
      <div class="comment-author">
         <span><?php echo get_avatar($comment,$size='48'); ?>
         <?php printf(__('<span class="fn">%s</span>','threestar'), get_comment_author_link()) ?> on
         <a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>"><?php printf(__('%1$s at %2$s', 'threestar'), get_comment_date(),  get_comment_time()) ?></a> said:
         <?php edit_comment_link(__('(Edit)', 'threestar'),'  ','') ?></span>
      </div>
      <?php if ($comment->comment_approved == '0') : ?>
         <em><?php _e('Your comment is awaiting moderation.', 'threestar') ?></em>
         <br />
      <?php endif; ?>
      <?php comment_text() ?>
      <div class="reply">
         <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
      </div>
     </div>
<?php
}

include_once('inc/contact-form.php');

/***shortcode section starts***/

//shortcode for large-12 columns
function threestar_one_column($atts, $content)
{	
	return '<div class="columns large-12">'.do_shortcode($content).'</div>';
}

add_shortcode( 'column_one', 'threestar_one_column' );

//shortcode for large-6 columns
function threestar_one_half_column($atts, $content)
{	
	return '<div class="columns large-6">'.do_shortcode($content).'</div>';
}

add_shortcode( 'one_half', 'threestar_one_half_column' );

//shortcode for large-4 columns
function threestar_one_third_column($atts, $content)
{
	return '<div class="columns large-4">'.do_shortcode($content).'</div>';
}

add_shortcode( 'column_one_third', 'threestar_one_third_column' );

//shortcode for large-3 columns
function threestar_one_fourth_column($atts, $content)
{
	return '<div class="columns large-3">'.do_shortcode($content).'</div>';
}

add_shortcode( 'column_one_fourth', 'threestar_one_fourth_column' );

//shortcode for large-9 columns
function threestar_two_third_column($atts, $content)
{
	return '<div class="columns large-9">'.do_shortcode($content).'</div>';
}

add_shortcode( 'column_two_third', 'threestar_two_third_column' );

//shortcode for gallery
function threestar_gallery_shortcode( $atts, $content ) {

	return '<div class="thumbnail-block"><ul class="large-block-grid-4 block-grid four-up">' . do_shortcode($content) . '</ul></div>';
}
add_shortcode( '3star_gallery', 'threestar_gallery_shortcode' );

//shortcode for gallery images
function threestar_gallery_image_shortcode( $atts, $content ) {
	extract(shortcode_atts(array(
       'title' => '',
	   'description' => '',
	   'imagelink' => ''
       ), $atts));
	   
	return '<li><a class="thumbnail" href="'.$imagelink.'" title="'.$title.'"><img src="'.$imagelink.'" /></a></li>';
}

add_shortcode( 'img', 'threestar_gallery_image_shortcode' );

//shortcode for gallery video
function threestar_gallery_video_shortcode( $atts, $content ) {
	extract(shortcode_atts(array(
	   'image' => '',
       'videolink' => '',
       ), $atts));
	   
	return '<li><a class="youtube" href="'.$videolink.'"><img src="'.$image.'" /></a></li>';
}
add_shortcode( '3star_video', 'threestar_gallery_video_shortcode' );

/***shortcodes section ends***/

/***gallery admin button***/

function add_threestargallery_button() {
   // Don't bother doing this stuff if the current user lacks permissions
   if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
     return;
 
   // Add only in Rich Editor mode
   if ( get_user_option('rich_editing') == 'true') {
     add_filter("mce_external_plugins", "add_threestargallery_tinymce_plugin");
     add_filter('mce_buttons', 'register_threestargallery_button');
   }
}
 
function register_threestargallery_button($buttons) {
   array_push($buttons, "|", "threestargallery");
   return $buttons;
}
 
// Load the TinyMCE plugin : editor_plugin.js (wp2.5)
function add_threestargallery_tinymce_plugin($plugin_array) {
   $plugin_array['threestargallery'] = get_template_directory_uri().'/js/gallery-shortcode.js';
   return $plugin_array;
}
 
function threestargallery_refresh_mce($ver) {
  $ver += 3;
  return $ver;
}

// init process for button control
add_filter( 'tiny_mce_version', 'threestargallery_refresh_mce');
add_action('init', 'add_threestargallery_button');


/***gallery admin button ends***/

/***columns admin button***/

function add_threestarcolumns_button() {
   // Don't bother doing this stuff if the current user lacks permissions
   if ( ! current_user_can('edit_posts') && ! current_user_can('edit_pages') )
     return;
 
   // Add only in Rich Editor mode
   if ( get_user_option('rich_editing') == 'true') {
     add_filter("mce_external_plugins", "add_threestarcolumns_tinymce_plugin");
     add_filter('mce_buttons', 'register_threestarcolumns_button');
   }
}
 
function register_threestarcolumns_button($buttons) {
   array_push($buttons, "|", "threestarcolumns");
   return $buttons;
}
 
// Load the TinyMCE plugin : editor_plugin.js (wp2.5)
function add_threestarcolumns_tinymce_plugin($plugin_array) {
   $plugin_array['threestarcolumns'] = get_template_directory_uri().'/js/columns-shortcode.js';
   return $plugin_array;
}
 
function threestarcolumns_refresh_mce($ver) {
  $ver += 3;
  return $ver;
}

// init process for button control
add_filter( 'tiny_mce_version', 'threestarcolumns_refresh_mce');
add_action('init', 'add_threestarcolumns_button');

/***columns admin button ends***/

?>
